@@ -1,6 +1,6 @@
 use v5.20;
 use warnings;
-package Log::Fmt 3.012;
+package Log::Fmt 3.013;
 # ABSTRACT: a little parser and emitter of structured log lines
 
 use experimental 'postderef'; # Not dangerous.  Is accepted without changed.
@@ -17,7 +17,7 @@ use String::Flogger ();
 #pod can scan tolerably well, and which a machine can parse about as well.  It can
 #pod also do that tolerably-okay parsing for you.
 #pod
-#pod =head1 SPECIFICATIN
+#pod =head1 SPECIFICATION
 #pod
 #pod =head2 The logfmt text format
 #pod
@@ -30,7 +30,7 @@ use String::Flogger ();
 #pod
 #pod     event = pair *(WSP pair)
 #pod     pair  = key "=" value
-#pod     okchr = %x21 / %x23-3c / %x3e-5b / %x5d-7e ; graphic ASCII, less: \ " = DEL
+#pod     okchr = %x21 / %x23-3c / %x3e-5b / %x5d-7e ; VCHAR minus \ and " and =
 #pod     key   = 1*(okchr)
 #pod     value = key / quoted
 #pod
@@ -50,7 +50,7 @@ use String::Flogger ();
 #pod possible to know whether a given codepoint is a non-ASCII unsafe character,
 #pod like C<LINE SEPARATOR>.  Safe non-ASCII characters can be directly UTF-8
 #pod encoded, rather than quoted with C<\x{...}>.  In that way, viewing logfmt events
-#pod with a standard termal can show something like:
+#pod with a standard terminal can show something like:
 #pod
 #pod     user.name="Jürgen"
 #pod
@@ -117,10 +117,10 @@ use String::Flogger ();
 #pod
 #pod =cut
 
-# okchr = %x21 / %x23-3c / %x3e-5b / %x5d-7e ; graphic ASCII, less: \ " = DEL
+# okchr = %x21 / %x23-3c / %x3e-5b / %x5d-7e ; VCHAR minus \ and " and =
 # key   = 1*(okchr)
 # value = key / quoted
-my $KEY_RE = qr{[\x21\x23-\x3C\x3E-\x5b\x5d-\x7E]+};
+my $KEY_RE = qr{[\x21\x23-\x3c\x3e-\x5b\x5d-\x7e]+};
 
 sub _escape_unprintable {
   my ($chr) = @_;
@@ -321,7 +321,7 @@ Log::Fmt - a little parser and emitter of structured log lines
 
 =head1 VERSION
 
-version 3.012
+version 3.013
 
 =head1 OVERVIEW
 
@@ -386,7 +386,7 @@ Because nothing prevents a single key from appearing more than once, you should
 use this with the understanding that data could be lost.  No guarantee is made
 of which value will be preserved.
 
-=head1 SPECIFICATIN
+=head1 SPECIFICATION
 
 =head2 The logfmt text format
 
@@ -399,7 +399,7 @@ separated by a single space.
 
     event = pair *(WSP pair)
     pair  = key "=" value
-    okchr = %x21 / %x23-3c / %x3e-5b / %x5d-7e ; graphic ASCII, less: \ " = DEL
+    okchr = %x21 / %x23-3c / %x3e-5b / %x5d-7e ; VCHAR minus \ and " and =
     key   = 1*(okchr)
     value = key / quoted
 
@@ -419,7 +419,7 @@ It is preferable to build quoted values from a Unicode string, because it's
 possible to know whether a given codepoint is a non-ASCII unsafe character,
 like C<LINE SEPARATOR>.  Safe non-ASCII characters can be directly UTF-8
 encoded, rather than quoted with C<\x{...}>.  In that way, viewing logfmt events
-with a standard termal can show something like:
+with a standard terminal can show something like:
 
     user.name="Jürgen"
 
